@@ -51,8 +51,9 @@ use PDL::Core;
 use PDL::Graphics::TriD;
 
 BEGIN {
+   use PDL::Config;
    if ( $PDL::Config{USE_POGL} ) {
-      eval 'use OpenGL 0.58_007 qw(:all)';
+      eval "use OpenGL $PDL::Config{POGL_VERSION} qw(:all)";
       eval 'use PDL::Graphics::OpenGL::Perl::OpenGL';
    } else {
       eval 'use PDL::Graphics::OpenGL';
